@@ -5,17 +5,34 @@
 // ambiguity with `nostd::variant` if compiled with Visual Studio 2015. Other
 // modern compilers are unaffected.
 #include <grpcpp/grpcpp.h>
+#include <grpcpp/security/credentials.h>
+#include <grpcpp/support/status.h>
+
+#include <stdint.h>
+#include <stdlib.h>
+#include <iostream>
+#include <string>
+#include <utility>
+#include "opentelemetry/context/propagation/global_propagator.h"
+#include "opentelemetry/context/propagation/text_map_propagator.h"
+#include "opentelemetry/context/runtime_context.h"
+#include "opentelemetry/nostd/shared_ptr.h"
+#include "opentelemetry/trace/propagation/http_trace_context.h"
+#include "opentelemetry/trace/span.h"
+#include "opentelemetry/trace/span_metadata.h"
+#include "opentelemetry/trace/span_startoptions.h"
+#include "opentelemetry/trace/tracer.h"
+
 #ifdef BAZEL_BUILD
 #  include "examples/grpc/protos/messages.grpc.pb.h"
+#  include "examples/grpc/protos/messages.pb.h"
 #else
 #  include "messages.grpc.pb.h"
+#  include "messages.pb.h"
 #endif
 
-#include <iostream>
-#include <memory>
-#include <string>
-
-#include "opentelemetry/trace/semantic_conventions.h"
+#include "opentelemetry/semconv/incubating/rpc_attributes.h"
+#include "opentelemetry/semconv/network_attributes.h"
 #include "tracer_common.h"
 
 using grpc::Channel;
@@ -29,6 +46,7 @@ using grpc_example::GreetResponse;
 namespace
 {
 namespace context = opentelemetry::context;
+namespace semconv = opentelemetry::semconv;
 using namespace opentelemetry::trace;
 class GreeterClient
 {
@@ -47,14 +65,14 @@ public:
     options.kind = SpanKind::kClient;
 
     std::string span_name = "GreeterClient/Greet";
-    auto span             = get_tracer("grpc")->StartSpan(
-        span_name,
-        {{SemanticConventions::kRpcSystem, "grpc"},
-                     {SemanticConventions::kRpcService, "grpc-example.GreetService"},
-                     {SemanticConventions::kRpcMethod, "Greet"},
-                     {SemanticConventions::kNetworkPeerAddress, ip},
-                     {SemanticConventions::kNetworkPeerPort, port}},
-        options);
+    auto span =
+        get_tracer("grpc")->StartSpan(span_name,
+                                      {{semconv::rpc::kRpcSystem, "grpc"},
+                                       {semconv::rpc::kRpcService, "grpc-example.GreetService"},
+                                       {semconv::rpc::kRpcMethod, "Greet"},
+                                       {semconv::network::kNetworkPeerAddress, ip},
+                                       {semconv::network::kNetworkPeerPort, port}},
+                                      options);
 
     auto scope = get_tracer("grpc-client")->WithActiveSpan(span);
 
@@ -69,7 +87,7 @@ public:
     if (status.ok())
     {
       span->SetStatus(StatusCode::kOk);
-      span->SetAttribute(SemanticConventions::kRpcGrpcStatusCode, status.error_code());
+      span->SetAttribute(semconv::rpc::kRpcGrpcStatusCode, status.error_code());
       // Make sure to end your spans!
       span->End();
       return response.response();
@@ -78,7 +96,7 @@ public:
     {
       std::cout << status.error_code() << ": " << status.error_message() << '\n';
       span->SetStatus(StatusCode::kError);
-      span->SetAttribute(SemanticConventions::kRpcGrpcStatusCode, status.error_code());
+      span->SetAttribute(semconv::rpc::kRpcGrpcStatusCode, status.error_code());
       // Make sure to end your spans!
       span->End();
       return "RPC failed";
