@@ -20,7 +20,6 @@
 #include "opentelemetry/sdk/metrics/meter_provider_factory.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
-#include "opentelemetry/sdk/metrics/state/filtered_ordered_attribute_map.h"
 #include "opentelemetry/sdk/metrics/view/instrument_selector.h"
 #include "opentelemetry/sdk/metrics/view/instrument_selector_factory.h"
 #include "opentelemetry/sdk/metrics/view/meter_selector.h"
@@ -148,16 +147,48 @@ int main(int argc, char **argv)
   {
     foo_library::histogram_example(name);
   }
+#if OPENTELEMETRY_ABI_VERSION_NO >= 2
+  else if (example_type == "gauge")
+  {
+    foo_library::gauge_example(name);
+  }
+#endif
+  else if (example_type == "semconv_counter")
+  {
+    foo_library::semconv_counter_example();
+  }
+  else if (example_type == "semconv_observable_counter")
+  {
+    foo_library::semconv_observable_counter_example();
+  }
+  else if (example_type == "semconv_histogram")
+  {
+    foo_library::semconv_histogram_example();
+  }
   else
   {
     std::thread counter_example{&foo_library::counter_example, name};
     std::thread observable_counter_example{&foo_library::observable_counter_example, name};
     std::thread histogram_example{&foo_library::histogram_example, name};
+#if OPENTELEMETRY_ABI_VERSION_NO >= 2
+    std::thread gauge_example{&foo_library::gauge_example, name};
+#endif
+    std::thread semconv_counter_example{&foo_library::semconv_counter_example};
+    std::thread semconv_observable_counter_example{
+        &foo_library::semconv_observable_counter_example};
+    std::thread semconv_histogram_example{&foo_library::semconv_histogram_example};
 
     counter_example.join();
     observable_counter_example.join();
     histogram_example.join();
+#if OPENTELEMETRY_ABI_VERSION_NO >= 2
+    gauge_example.join();
+#endif
+    semconv_counter_example.join();
+    semconv_observable_counter_example.join();
+    semconv_histogram_example.join();
   }
 
   CleanupMetrics();
+  return 0;
 }
