@@ -28,20 +28,18 @@ class ElasticSearchRecordable final : public sdk::logs::Recordable
 {
 private:
   /**
-   * A helper method that writes a key/value pair under a specified name, the two names used here
-   * being "attributes" and "resources"
+   * A helper method that writes a value under a specified name.
+   * `name` will be at the root of the JSON object. If it has to be nested under some other keys,
+   * then write `name` as `key1.key2.[...].name`
    */
-  void WriteKeyValue(nostd::string_view key,
-                     const opentelemetry::common::AttributeValue &value,
-                     const std::string &name);
-
-  void WriteKeyValue(nostd::string_view key,
-                     const opentelemetry::sdk::common::OwnedAttributeValue &value,
-                     const std::string &name);
+  void WriteValue(const opentelemetry::sdk::common::OwnedAttributeValue &value,
+                  const std::string &name);
 
   void WriteValue(const opentelemetry::common::AttributeValue &value, const std::string &name);
 
 public:
+  ElasticSearchRecordable() noexcept;
+
   /**
    * Returns a JSON object contain the log information
    */
