@@ -1,40 +1,10 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include "opentelemetry/exporters/otlp/otlp_file_client.h"
-
-#if defined(HAVE_GSL)
-#  include <gsl/gsl>
-#else
-#  include <assert.h>
-#endif
-
-// clang-format off
-#include "opentelemetry/exporters/otlp/protobuf_include_prefix.h" // IWYU pragma: keep
-// clang-format on
-
-#include "google/protobuf/message.h"
-#include "nlohmann/json.hpp"
-
-// clang-format off
-#include "opentelemetry/exporters/otlp/protobuf_include_suffix.h" // IWYU pragma: keep
-// clang-format on
-
-#include "opentelemetry/nostd/string_view.h"
-#include "opentelemetry/nostd/variant.h"
-#include "opentelemetry/sdk/common/base64.h"
-#include "opentelemetry/sdk/common/global_log_handler.h"
-#include "opentelemetry/version.h"
-
-#ifdef _MSC_VER
-#  include <string.h>
-#  define strcasecmp _stricmp
-#else
-#  include <strings.h>
-#endif
-
 #include <limits.h>
+#include <algorithm>
 #include <atomic>
+#include <chrono>
 #include <condition_variable>
 #include <cstdint>
 #include <cstdio>
@@ -43,12 +13,26 @@
 #include <fstream>
 #include <functional>
 #include <mutex>
+#include <nlohmann/json.hpp>
+#include <ratio>
 #include <string>
 #include <thread>
 #include <utility>
 #include <vector>
-#if OPENTELEMETRY_HAVE_EXCEPTIONS
-#  include <exception>
+
+// IWYU pragma: no_include <features.h>
+
+#if defined(HAVE_GSL)
+#  include <gsl/gsl>
+#else
+#  include <assert.h>
+#endif
+
+#ifdef _MSC_VER
+#  include <string.h>
+#  define strcasecmp _stricmp
+#else
+#  include <strings.h>
 #endif
 
 #if !defined(__CYGWIN__) && defined(_WIN32)
@@ -78,6 +62,7 @@
 
 #  include <fcntl.h>
 #  include <sys/stat.h>
+#  include <sys/types.h>
 #  include <unistd.h>
 
 #  define FS_ACCESS(x) access(x, F_OK)
@@ -120,6 +105,31 @@
 #  define OTLP_FILE_OPEN(f, path, mode) f = fopen(path, mode)
 #endif
 
+#include "opentelemetry/exporters/otlp/otlp_file_client.h"
+#include "opentelemetry/exporters/otlp/otlp_file_client_options.h"
+#include "opentelemetry/exporters/otlp/otlp_file_client_runtime_options.h"
+#include "opentelemetry/nostd/shared_ptr.h"
+#include "opentelemetry/nostd/string_view.h"
+#include "opentelemetry/nostd/variant.h"
+#include "opentelemetry/sdk/common/base64.h"
+#include "opentelemetry/sdk/common/exporter_utils.h"
+#include "opentelemetry/sdk/common/global_log_handler.h"
+#include "opentelemetry/sdk/common/thread_instrumentation.h"
+#include "opentelemetry/version.h"
+
+// clang-format off
+#include "opentelemetry/exporters/otlp/protobuf_include_prefix.h" // IWYU pragma: keep
+#include "google/protobuf/descriptor.h"
+#include "google/protobuf/message.h"
+#include "opentelemetry/exporters/otlp/protobuf_include_suffix.h" // IWYU pragma: keep
+// clang-format on
+
+// Must be included after opentelemetry/version.h,
+// which exports opentelemetry/common/macros.h
+#if OPENTELEMETRY_HAVE_EXCEPTIONS
+#  include <exception>
+#endif
+
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace exporter
 {
@@ -965,10 +975,10 @@ void ConvertListFieldToJson(nlohmann::json &value,
 class OPENTELEMETRY_LOCAL_SYMBOL OtlpFileSystemBackend : public OtlpFileAppender
 {
 public:
-  explicit OtlpFileSystemBackend(const OtlpFileClientFileSystemOptions &options)
-      : options_(options), is_initialized_{false}
+  explicit OtlpFileSystemBackend(const OtlpFileClientFileSystemOptions &options,
+                                 const OtlpFileClientRuntimeOptions &runtime_options)
+      : options_(options), runtime_options_(runtime_options), is_initialized_{false}
   {
-    file_ = std::make_shared<FileStats>();
     file_->is_shutdown.store(false);
     file_->rotate_index            = 0;
     file_->written_size            = 0;
@@ -1440,11 +1450,20 @@ private:
 
       std::shared_ptr<FileStats> concurrency_file = file_;
       std::chrono::microseconds flush_interval    = options_.flush_interval;
-      file_->background_flush_thread.reset(new std::thread([concurrency_file, flush_interval]() {
+      auto thread_instrumentation                 = runtime_options_.thread_instrumentation;
+      file_->background_flush_thread.reset(new std::thread([concurrency_file, flush_interval,
+                                                            thread_instrumentation]() {
         std::chrono::system_clock::time_point last_free_job_timepoint =
             std::chrono::system_clock::now();
         std::size_t last_record_count = 0;
 
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+        if (thread_instrumentation != nullptr)
+        {
+          thread_instrumentation->OnStart();
+        }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
         while (true)
         {
           std::chrono::system_clock::time_point now = std::chrono::system_clock::now();
@@ -1459,11 +1478,25 @@ private:
             break;
           }
 
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+          if (thread_instrumentation != nullptr)
+          {
+            thread_instrumentation->BeforeWait();
+          }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
           {
             std::unique_lock<std::mutex> lk(concurrency_file->background_thread_waker_lock);
             concurrency_file->background_thread_waker_cv.wait_for(lk, flush_interval);
           }
 
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+          if (thread_instrumentation != nullptr)
+          {
+            thread_instrumentation->AfterWait();
+          }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
           {
             std::size_t current_record_count =
                 concurrency_file->record_count.load(std::memory_order_acquire);
@@ -1492,6 +1525,14 @@ private:
           std::lock_guard<std::mutex> lock_guard_inner{concurrency_file->background_thread_lock};
           background_flush_thread.swap(concurrency_file->background_flush_thread);
         }
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+        if (thread_instrumentation != nullptr)
+        {
+          thread_instrumentation->OnEnd();
+        }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
         if (background_flush_thread && background_flush_thread->joinable())
         {
           background_flush_thread->detach();
@@ -1515,6 +1556,7 @@ private:
 
 private:
   OtlpFileClientFileSystemOptions options_;
+  OtlpFileClientRuntimeOptions runtime_options_;
 
   struct FileStats
   {
@@ -1536,9 +1578,9 @@ private:
     std::mutex background_thread_waiter_lock;
     std::condition_variable background_thread_waiter_cv;
   };
-  std::shared_ptr<FileStats> file_;
+  std::shared_ptr<FileStats> file_ = std::make_shared<FileStats>();
 
-  std::atomic<bool> is_initialized_;
+  std::atomic<bool> is_initialized_{false};
   std::time_t check_file_path_interval_{0};
 };
 
@@ -1567,13 +1609,16 @@ private:
   std::reference_wrapper<std::ostream> os_;
 };
 
-OtlpFileClient::OtlpFileClient(OtlpFileClientOptions &&options)
-    : is_shutdown_(false), options_(std::move(options))
+OtlpFileClient::OtlpFileClient(OtlpFileClientOptions &&options,
+                               OtlpFileClientRuntimeOptions &&runtime_options)
+    : is_shutdown_(false),
+      options_(std::move(options)),
+      runtime_options_(std::move(runtime_options))
 {
   if (nostd::holds_alternative<OtlpFileClientFileSystemOptions>(options_.backend_options))
   {
     backend_ = opentelemetry::nostd::shared_ptr<OtlpFileAppender>(new OtlpFileSystemBackend(
-        nostd::get<OtlpFileClientFileSystemOptions>(options_.backend_options)));
+        nostd::get<OtlpFileClientFileSystemOptions>(options_.backend_options), runtime_options_));
   }
   else if (nostd::holds_alternative<std::reference_wrapper<std::ostream>>(options_.backend_options))
   {
