@@ -12,6 +12,7 @@
 #include <atomic>
 #include <chrono>
 #include <condition_variable>
+#include <cstdio>
 #include <fstream>
 #include <iterator>
 #include <memory>
@@ -23,6 +24,7 @@
 #include "opentelemetry/common/timestamp.h"
 #include "opentelemetry/ext/http/common/url_parser.h"
 #include "opentelemetry/nostd/function_ref.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -78,16 +80,20 @@ public:
   virtual ~OtlpGrpcAsyncCallData() {}
 };
 }  // namespace
+#endif
 
 struct OtlpGrpcClientAsyncData
 {
+
   std::chrono::system_clock::duration export_timeout = std::chrono::seconds{10};
 
   // The best performance trade-off of gRPC is having numcpu's threads and one completion queue
   // per thread, but this exporter should not cost a lot resource and we don't want to create
-  // too many threads in the process. So we use one completion queue.
-  grpc::CompletionQueue cq;
-
+  // too many threads in the process. So we use one completion queue and shared context.
+  std::shared_ptr<grpc::Channel> channel;
+#ifdef ENABLE_ASYNC_EXPORT
+  std::mutex running_calls_lock;
+  std::unordered_set<std::shared_ptr<OtlpGrpcAsyncCallDataBase>> running_calls;
   // Running requests, this is used to limit the number of concurrent requests.
   std::atomic<std::size_t> running_requests{0};
   // Request counter is used to record ForceFlush.
@@ -98,13 +104,16 @@ struct OtlpGrpcClientAsyncData
   // Condition variable and mutex to control the concurrency count of running requests.
   std::mutex session_waker_lock;
   std::condition_variable session_waker;
+#endif
+
+  // Reference count of OtlpGrpcClient
+  std::atomic<int64_t> reference_count{0};
 
   // Do not use OtlpGrpcClientAsyncData() = default; here, some versions of GCC&Clang have BUGs
   // and may not initialize the member correctly. See also
   // https://stackoverflow.com/questions/53408962/try-to-understand-compiler-error-message-default-member-initializer-required-be
   OtlpGrpcClientAsyncData() {}
 };
-#endif
 
 namespace
 {
@@ -199,6 +208,11 @@ static sdk::common::ExportResult InternalDelegateAsyncExport(
 
   ++async_data->start_request_counter;
   ++async_data->running_requests;
+  {
+    std::lock_guard<std::mutex> lock{async_data->running_calls_lock};
+    async_data->running_calls.insert(
+        std::static_pointer_cast<OtlpGrpcAsyncCallDataBase>(call_data));
+  }
   // Some old toolchains can only use gRPC 1.33 and it's experimental.
 #  if defined(GRPC_CPP_VERSION_MAJOR) && \
       (GRPC_CPP_VERSION_MAJOR * 1000 + GRPC_CPP_VERSION_MINOR) >= 1039
@@ -207,7 +221,13 @@ static sdk::common::ExportResult InternalDelegateAsyncExport(
   stub->experimental_async()
 #  endif
       ->Export(call_data->grpc_context.get(), call_data->request, call_data->response,
-               [call_data, async_data](::grpc::Status grpc_status) {
+               [call_data, async_data, export_data_name](::grpc::Status grpc_status) {
+                 {
+                   std::lock_guard<std::mutex> lock{async_data->running_calls_lock};
+                   async_data->running_calls.erase(
+                       std::static_pointer_cast<OtlpGrpcAsyncCallDataBase>(call_data));
+                 }
+
                  --async_data->running_requests;
                  ++async_data->finished_request_counter;
 
@@ -216,6 +236,13 @@ static sdk::common::ExportResult InternalDelegateAsyncExport(
                  {
                    call_data->export_result = opentelemetry::sdk::common::ExportResult::kSuccess;
                  }
+                 else
+                 {
+                   OTEL_INTERNAL_LOG_ERROR("[OTLP GRPC Client] ERROR: Export "
+                                           << export_data_name << " failed with status_code: \""
+                                           << grpc_status.error_code() << "\" error_message: \""
+                                           << grpc_status.error_message() << "\"");
+                 }
 
                  if (call_data->grpc_async_callback)
                  {
@@ -240,18 +267,38 @@ static sdk::common::ExportResult InternalDelegateAsyncExport(
 #endif
 }  // namespace
 
-OtlpGrpcClient::OtlpGrpcClient()
-#ifdef ENABLE_ASYNC_EXPORT
-    : is_shutdown_(false)
-#endif
-{}
+OtlpGrpcClientReferenceGuard::OtlpGrpcClientReferenceGuard() noexcept : has_value_{false} {}
+
+OtlpGrpcClientReferenceGuard::~OtlpGrpcClientReferenceGuard() noexcept {}
+
+OtlpGrpcClient::OtlpGrpcClient(const OtlpGrpcClientOptions &options) : is_shutdown_(false)
+{
+  std::shared_ptr<OtlpGrpcClientAsyncData> async_data = MutableAsyncData(options);
+  async_data->channel                                 = MakeChannel(options);
+}
 
 OtlpGrpcClient::~OtlpGrpcClient()
 {
-#ifdef ENABLE_ASYNC_EXPORT
   std::shared_ptr<OtlpGrpcClientAsyncData> async_data;
   async_data.swap(async_data_);
 
+#ifdef ENABLE_ASYNC_EXPORT
+  if (async_data)
+  {
+    std::unordered_set<std::shared_ptr<OtlpGrpcAsyncCallDataBase>> running_calls;
+    {
+      std::lock_guard<std::mutex> lock(async_data->running_calls_lock);
+      running_calls = async_data->running_calls;
+    }
+    for (auto &call_data : running_calls)
+    {
+      if (call_data && call_data->grpc_context)
+      {
+        call_data->grpc_context->TryCancel();
+      }
+    }
+  }
+
   while (async_data && async_data->running_requests.load(std::memory_order_acquire) > 0)
   {
     std::unique_lock<std::mutex> lock{async_data->session_waker_lock};
@@ -302,6 +349,49 @@ std::shared_ptr<grpc::Channel> OtlpGrpcClient::MakeChannel(const OtlpGrpcClientO
     grpc_arguments.SetCompressionAlgorithm(GRPC_COMPRESS_GZIP);
   }
 
+#ifdef ENABLE_OTLP_RETRY_PREVIEW
+  if (options.retry_policy_max_attempts > 0U &&
+      options.retry_policy_initial_backoff > std::chrono::duration<float>::zero() &&
+      options.retry_policy_max_backoff > std::chrono::duration<float>::zero() &&
+      options.retry_policy_backoff_multiplier > 0.0f)
+  {
+    static const auto kServiceConfigJson = opentelemetry::nostd::string_view{R"(
+    {
+      "methodConfig": [
+        {
+          "name": [{}],
+          "retryPolicy": {
+            "maxAttempts": %0000000000u,
+            "initialBackoff": "%0000000000.1fs",
+            "maxBackoff": "%0000000000.1fs",
+            "backoffMultiplier": %0000000000.1f,
+            "retryableStatusCodes": [
+              "CANCELLED",
+              "DEADLINE_EXCEEDED",
+              "ABORTED",
+              "OUT_OF_RANGE",
+              "DATA_LOSS",
+              "UNAVAILABLE"
+            ]
+          }
+        }
+      ]
+    })"};
+
+    // Allocate string with buffer large enough to hold the formatted json config
+    auto service_config = std::string(kServiceConfigJson.size(), '\0');
+    // Prior to C++17, need to explicitly cast away constness from `data()` buffer
+    std::snprintf(
+        const_cast<decltype(service_config)::value_type *>(service_config.data()),
+        service_config.size(), kServiceConfigJson.data(), options.retry_policy_max_attempts,
+        std::min(std::max(options.retry_policy_initial_backoff.count(), 0.f), 999999999.f),
+        std::min(std::max(options.retry_policy_max_backoff.count(), 0.f), 999999999.f),
+        std::min(std::max(options.retry_policy_backoff_multiplier, 0.f), 999999999.f));
+
+    grpc_arguments.SetServiceConfigJSON(service_config);
+  }
+#endif  // ENABLE_OTLP_RETRY_PREVIEW
+
   if (options.use_ssl_credentials)
   {
     grpc::SslCredentialsOptions ssl_opts;
@@ -350,21 +440,33 @@ std::unique_ptr<grpc::ClientContext> OtlpGrpcClient::MakeClientContext(
 }
 
 std::unique_ptr<proto::collector::trace::v1::TraceService::StubInterface>
-OtlpGrpcClient::MakeTraceServiceStub(const OtlpGrpcClientOptions &options)
+OtlpGrpcClient::MakeTraceServiceStub()
 {
-  return proto::collector::trace::v1::TraceService::NewStub(MakeChannel(options));
+  if (!async_data_ || !async_data_->channel)
+  {
+    return nullptr;
+  }
+  return proto::collector::trace::v1::TraceService::NewStub(async_data_->channel);
 }
 
 std::unique_ptr<proto::collector::metrics::v1::MetricsService::StubInterface>
-OtlpGrpcClient::MakeMetricsServiceStub(const OtlpGrpcClientOptions &options)
+OtlpGrpcClient::MakeMetricsServiceStub()
 {
-  return proto::collector::metrics::v1::MetricsService::NewStub(MakeChannel(options));
+  if (!async_data_ || !async_data_->channel)
+  {
+    return nullptr;
+  }
+  return proto::collector::metrics::v1::MetricsService::NewStub(async_data_->channel);
 }
 
 std::unique_ptr<proto::collector::logs::v1::LogsService::StubInterface>
-OtlpGrpcClient::MakeLogsServiceStub(const OtlpGrpcClientOptions &options)
+OtlpGrpcClient::MakeLogsServiceStub()
 {
-  return proto::collector::logs::v1::LogsService::NewStub(MakeChannel(options));
+  if (!async_data_ || !async_data_->channel)
+  {
+    return nullptr;
+  }
+  return proto::collector::logs::v1::LogsService::NewStub(async_data_->channel);
 }
 
 grpc::Status OtlpGrpcClient::DelegateExport(
@@ -397,6 +499,35 @@ grpc::Status OtlpGrpcClient::DelegateExport(
   return stub->Export(context.get(), request, response);
 }
 
+void OtlpGrpcClient::AddReference(OtlpGrpcClientReferenceGuard &guard,
+                                  const OtlpGrpcClientOptions &options) noexcept
+{
+  if (false == guard.has_value_.exchange(true, std::memory_order_acq_rel))
+  {
+    MutableAsyncData(options)->reference_count.fetch_add(1, std::memory_order_acq_rel);
+  }
+}
+
+bool OtlpGrpcClient::RemoveReference(OtlpGrpcClientReferenceGuard &guard) noexcept
+{
+  auto async_data = async_data_;
+  if (true == guard.has_value_.exchange(false, std::memory_order_acq_rel))
+  {
+    if (async_data)
+    {
+      int64_t left = async_data->reference_count.fetch_sub(1, std::memory_order_acq_rel);
+      return left <= 1;
+    }
+  }
+
+  if (async_data)
+  {
+    return async_data->reference_count.load(std::memory_order_acquire) <= 0;
+  }
+
+  return true;
+}
+
 #ifdef ENABLE_ASYNC_EXPORT
 
 /**
@@ -500,26 +631,37 @@ sdk::common::ExportResult OtlpGrpcClient::DelegateAsyncExport(
                                      "log(s)");
 }
 
+#endif
+
 std::shared_ptr<OtlpGrpcClientAsyncData> OtlpGrpcClient::MutableAsyncData(
     const OtlpGrpcClientOptions &options)
 {
   if (!async_data_)
   {
-    async_data_                          = std::make_shared<OtlpGrpcClientAsyncData>();
-    async_data_->export_timeout          = options.timeout;
+    async_data_                 = std::make_shared<OtlpGrpcClientAsyncData>();
+    async_data_->export_timeout = options.timeout;
+#ifdef ENABLE_ASYNC_EXPORT
     async_data_->max_concurrent_requests = options.max_concurrent_requests;
+#endif
   }
 
   return async_data_;
 }
 
-bool OtlpGrpcClient::ForceFlush(std::chrono::microseconds timeout) noexcept
+bool OtlpGrpcClient::IsShutdown() const noexcept
+{
+  return is_shutdown_.load(std::memory_order_acquire);
+}
+
+bool OtlpGrpcClient::ForceFlush(
+    OPENTELEMETRY_MAYBE_UNUSED std::chrono::microseconds timeout) noexcept
 {
   if (!async_data_)
   {
     return true;
   }
 
+#ifdef ENABLE_ASYNC_EXPORT
   std::size_t request_counter = async_data_->start_request_counter.load(std::memory_order_acquire);
   if (request_counter <= async_data_->finished_request_counter.load(std::memory_order_acquire))
   {
@@ -558,21 +700,46 @@ bool OtlpGrpcClient::ForceFlush(std::chrono::microseconds timeout) noexcept
   }
 
   return timeout_steady > std::chrono::steady_clock::duration::zero();
+#else
+  return true;
+#endif
 }
 
-bool OtlpGrpcClient::Shutdown(std::chrono::microseconds timeout) noexcept
+bool OtlpGrpcClient::Shutdown(OtlpGrpcClientReferenceGuard &guard,
+                              OPENTELEMETRY_MAYBE_UNUSED std::chrono::microseconds timeout) noexcept
 {
   if (!async_data_)
   {
     return true;
   }
 
+  bool last_reference_removed = RemoveReference(guard);
   bool force_flush_result;
-  if (false == is_shutdown_.exchange(true, std::memory_order_acq_rel))
+  if (last_reference_removed && false == is_shutdown_.exchange(true, std::memory_order_acq_rel))
   {
+    OTEL_INTERNAL_LOG_DEBUG("[OTLP GRPC Client] DEBUG: OtlpGrpcClient start to shutdown");
     force_flush_result = ForceFlush(timeout);
 
-    async_data_->cq.Shutdown();
+#ifdef ENABLE_ASYNC_EXPORT
+    std::unordered_set<std::shared_ptr<OtlpGrpcAsyncCallDataBase>> running_calls;
+    {
+      std::lock_guard<std::mutex> lock(async_data_->running_calls_lock);
+      running_calls = async_data_->running_calls;
+    }
+    if (!running_calls.empty())
+    {
+      OTEL_INTERNAL_LOG_WARN(
+          "[OTLP GRPC Client] WARN: OtlpGrpcClient shutdown timeout, try to cancel "
+          << running_calls.size() << " running calls.");
+    }
+    for (auto &call_data : running_calls)
+    {
+      if (call_data && call_data->grpc_context)
+      {
+        call_data->grpc_context->TryCancel();
+      }
+    }
+#endif
   }
   else
   {
@@ -582,8 +749,6 @@ bool OtlpGrpcClient::Shutdown(std::chrono::microseconds timeout) noexcept
   return force_flush_result;
 }
 
-#endif
-
 }  // namespace otlp
 }  // namespace exporter
 OPENTELEMETRY_END_NAMESPACE
