@@ -6,6 +6,7 @@
 
 #include "opentelemetry/common/macros.h"
 #include "opentelemetry/exporters/otlp/otlp_grpc_client.h"
+#include "opentelemetry/exporters/otlp/otlp_grpc_client_factory.h"
 #include "opentelemetry/exporters/otlp/otlp_grpc_metric_exporter.h"
 #include "opentelemetry/exporters/otlp/otlp_metric_utils.h"
 
@@ -24,24 +25,61 @@ OtlpGrpcMetricExporter::OtlpGrpcMetricExporter()
 
 OtlpGrpcMetricExporter::OtlpGrpcMetricExporter(const OtlpGrpcMetricExporterOptions &options)
     : options_(options),
-#ifdef ENABLE_ASYNC_EXPORT
-      client_(std::make_shared<OtlpGrpcClient>()),
-#endif
       aggregation_temporality_selector_{
-          OtlpMetricUtils::ChooseTemporalitySelector(options_.aggregation_temporality)},
-      metrics_service_stub_(OtlpGrpcClient::MakeMetricsServiceStub(options))
-{}
+          OtlpMetricUtils::ChooseTemporalitySelector(options_.aggregation_temporality)}
+{
+  client_                 = OtlpGrpcClientFactory::Create(options_);
+  client_reference_guard_ = OtlpGrpcClientFactory::CreateReferenceGuard();
+  client_->AddReference(*client_reference_guard_, options_);
+
+  metrics_service_stub_ = client_->MakeMetricsServiceStub();
+}
 
 OtlpGrpcMetricExporter::OtlpGrpcMetricExporter(
     std::unique_ptr<proto::collector::metrics::v1::MetricsService::StubInterface> stub)
     : options_(OtlpGrpcMetricExporterOptions()),
-#ifdef ENABLE_ASYNC_EXPORT
-      client_(std::make_shared<OtlpGrpcClient>()),
-#endif
       aggregation_temporality_selector_{
           OtlpMetricUtils::ChooseTemporalitySelector(options_.aggregation_temporality)},
       metrics_service_stub_(std::move(stub))
-{}
+{
+  client_                 = OtlpGrpcClientFactory::Create(options_);
+  client_reference_guard_ = OtlpGrpcClientFactory::CreateReferenceGuard();
+  client_->AddReference(*client_reference_guard_, options_);
+}
+
+OtlpGrpcMetricExporter::OtlpGrpcMetricExporter(const OtlpGrpcMetricExporterOptions &options,
+                                               const std::shared_ptr<OtlpGrpcClient> &client)
+    : options_(options),
+      client_(client),
+      client_reference_guard_(OtlpGrpcClientFactory::CreateReferenceGuard()),
+      aggregation_temporality_selector_{
+          OtlpMetricUtils::ChooseTemporalitySelector(options_.aggregation_temporality)}
+{
+  client_->AddReference(*client_reference_guard_, options_);
+
+  metrics_service_stub_ = client_->MakeMetricsServiceStub();
+}
+
+OtlpGrpcMetricExporter::OtlpGrpcMetricExporter(
+    std::unique_ptr<proto::collector::metrics::v1::MetricsService::StubInterface> stub,
+    const std::shared_ptr<OtlpGrpcClient> &client)
+    : options_(OtlpGrpcMetricExporterOptions()),
+      client_(client),
+      client_reference_guard_(OtlpGrpcClientFactory::CreateReferenceGuard()),
+      aggregation_temporality_selector_{
+          OtlpMetricUtils::ChooseTemporalitySelector(options_.aggregation_temporality)},
+      metrics_service_stub_(std::move(stub))
+{
+  client_->AddReference(*client_reference_guard_, options_);
+}
+
+OtlpGrpcMetricExporter::~OtlpGrpcMetricExporter()
+{
+  if (client_)
+  {
+    client_->RemoveReference(*client_reference_guard_);
+  }
+}
 
 // ----------------------------- Exporter methods ------------------------------
 
@@ -54,14 +92,23 @@ sdk::metrics::AggregationTemporality OtlpGrpcMetricExporter::GetAggregationTempo
 opentelemetry::sdk::common::ExportResult OtlpGrpcMetricExporter::Export(
     const opentelemetry::sdk::metrics::ResourceMetrics &data) noexcept
 {
-
-  if (isShutdown())
+  std::shared_ptr<OtlpGrpcClient> client = client_;
+  if (isShutdown() || !client)
   {
     OTEL_INTERNAL_LOG_ERROR("[OTLP METRICS gRPC] Exporting "
                             << data.scope_metric_data_.size()
                             << " metric(s) failed, exporter is shutdown");
     return sdk::common::ExportResult::kFailure;
   }
+
+  if (!metrics_service_stub_)
+  {
+    OTEL_INTERNAL_LOG_ERROR("[OTLP gRPC] Exporting "
+                            << data.scope_metric_data_.size()
+                            << " metric(s) failed, service stub unavailable");
+    return sdk::common::ExportResult::kFailure;
+  }
+
   if (data.scope_metric_data_.empty())
   {
     return sdk::common::ExportResult::kSuccess;
@@ -88,13 +135,16 @@ opentelemetry::sdk::common::ExportResult OtlpGrpcMetricExporter::Export(
 #ifdef ENABLE_ASYNC_EXPORT
   if (options_.max_concurrent_requests > 1)
   {
-    return client_->DelegateAsyncExport(
+    return client->DelegateAsyncExport(
         options_, metrics_service_stub_.get(), std::move(context), std::move(arena),
         std::move(*request),
-        [](opentelemetry::sdk::common::ExportResult result,
-           std::unique_ptr<google::protobuf::Arena> &&,
-           const proto::collector::metrics::v1::ExportMetricsServiceRequest &request,
-           proto::collector::metrics::v1::ExportMetricsServiceResponse *) {
+        // Capture the metrics_service_stub_ to ensure it is not destroyed before the callback is
+        // called.
+        [metrics_service_stub = metrics_service_stub_](
+            opentelemetry::sdk::common::ExportResult result,
+            std::unique_ptr<google::protobuf::Arena> &&,
+            const proto::collector::metrics::v1::ExportMetricsServiceRequest &request,
+            proto::collector::metrics::v1::ExportMetricsServiceResponse *) {
           if (result != opentelemetry::sdk::common::ExportResult::kSuccess)
           {
             OTEL_INTERNAL_LOG_ERROR("[OTLP METRIC GRPC Exporter] ERROR: Export "
@@ -131,22 +181,27 @@ opentelemetry::sdk::common::ExportResult OtlpGrpcMetricExporter::Export(
 bool OtlpGrpcMetricExporter::ForceFlush(
     OPENTELEMETRY_MAYBE_UNUSED std::chrono::microseconds timeout) noexcept
 {
-#ifdef ENABLE_ASYNC_EXPORT
-  return client_->ForceFlush(timeout);
-#else
-  return true;
-#endif
+  // Maybe already shutdown, we need to keep thread-safety here.
+  std::shared_ptr<OtlpGrpcClient> client = client_;
+  if (!client)
+  {
+    return true;
+  }
+  return client->ForceFlush(timeout);
 }
 
 bool OtlpGrpcMetricExporter::Shutdown(
     OPENTELEMETRY_MAYBE_UNUSED std::chrono::microseconds timeout) noexcept
 {
   is_shutdown_ = true;
-#ifdef ENABLE_ASYNC_EXPORT
-  return client_->Shutdown(timeout);
-#else
-  return true;
-#endif
+  // Maybe already shutdown, we need to keep thread-safety here.
+  std::shared_ptr<OtlpGrpcClient> client;
+  client.swap(client_);
+  if (!client)
+  {
+    return true;
+  }
+  return client->Shutdown(*client_reference_guard_, timeout);
 }
 
 bool OtlpGrpcMetricExporter::isShutdown() const noexcept
@@ -154,6 +209,11 @@ bool OtlpGrpcMetricExporter::isShutdown() const noexcept
   return is_shutdown_;
 }
 
+const std::shared_ptr<OtlpGrpcClient> &OtlpGrpcMetricExporter::GetClient() const noexcept
+{
+  return client_;
+}
+
 }  // namespace otlp
 }  // namespace exporter
 OPENTELEMETRY_END_NAMESPACE
