@@ -1,8 +1,18 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
+#include <prometheus/metric_family.h>
+#include <algorithm>
+#include <mutex>
+#include <vector>
+
 #include "opentelemetry/exporters/prometheus/collector.h"
+#include "opentelemetry/exporters/prometheus/exporter_utils.h"
+#include "opentelemetry/nostd/function_ref.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
+#include "opentelemetry/sdk/metrics/export/metric_producer.h"
+#include "opentelemetry/sdk/metrics/metric_reader.h"
+#include "opentelemetry/version.h"
 
 namespace metric_sdk = opentelemetry::sdk::metrics;
 
