@@ -4,16 +4,23 @@
 #include <curl/curl.h>
 #include <curl/curlver.h>
 #include <curl/system.h>
+
+#ifdef ENABLE_OTLP_RETRY_PREVIEW
+#  include <array>
+#endif  // ENABLE_OTLP_RETRY_PREVIEW
+
 #include <algorithm>
 #include <atomic>
 #include <chrono>
-#include <cstdint>
+#include <cmath>
 #include <cstring>
 #include <functional>
 #include <future>
-#include <istream>
 #include <map>
 #include <memory>
+#include <random>
+#include <ratio>
+#include <sstream>
 #include <string>
 #include <thread>
 #include <utility>
@@ -22,6 +29,7 @@
 #include "opentelemetry/ext/http/client/curl/http_client_curl.h"
 #include "opentelemetry/ext/http/client/curl/http_operation_curl.h"
 #include "opentelemetry/ext/http/client/http_client.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
 #include "opentelemetry/version.h"
 
@@ -261,7 +269,9 @@ HttpOperation::HttpOperation(opentelemetry::ext::http::client::Method method,
                              // Default connectivity and response size options
                              bool is_raw_response,
                              std::chrono::milliseconds http_conn_timeout,
-                             bool reuse_connection)
+                             bool reuse_connection,
+                             bool is_log_enabled,
+                             const RetryPolicy &retry_policy)
     : is_aborted_(false),
       is_finished_(false),
       is_cleaned_(false),
@@ -281,6 +291,14 @@ HttpOperation::HttpOperation(opentelemetry::ext::http::client::Method method,
       request_nwrite_(0),
       session_state_(opentelemetry::ext::http::client::SessionState::Created),
       compression_(compression),
+      is_log_enabled_(is_log_enabled),
+      retry_policy_(retry_policy),
+      retry_attempts_((retry_policy.max_attempts > 0U &&
+                       retry_policy.initial_backoff > SecondsDecimal::zero() &&
+                       retry_policy.max_backoff > SecondsDecimal::zero() &&
+                       retry_policy.backoff_multiplier > 0.0f)
+                          ? 0
+                          : retry_policy.max_attempts),
       response_code_(0)
 {
   /* get a curl handle */
@@ -298,9 +316,7 @@ HttpOperation::HttpOperation(opentelemetry::ext::http::client::Method method,
   {
     for (auto &kv : this->request_headers_)
     {
-      std::string header = std::string(kv.first);
-      header += ": ";
-      header += std::string(kv.second);
+      const auto header = std::string(kv.first).append(": ").append(kv.second);
       curl_resource_.headers_chunk =
           curl_slist_append(curl_resource_.headers_chunk, header.c_str());
     }
@@ -425,6 +441,53 @@ void HttpOperation::Cleanup()
   }
 }
 
+bool HttpOperation::IsRetryable()
+{
+#ifdef ENABLE_OTLP_RETRY_PREVIEW
+  static constexpr auto kRetryableStatusCodes = std::array<decltype(response_code_), 4>{
+      429,  // Too Many Requests
+      502,  // Bad Gateway
+      503,  // Service Unavailable
+      504   // Gateway Timeout
+  };
+
+  const auto is_retryable = std::find(kRetryableStatusCodes.cbegin(), kRetryableStatusCodes.cend(),
+                                      response_code_) != kRetryableStatusCodes.cend();
+
+  return is_retryable && (last_curl_result_ == CURLE_OK) &&
+         (retry_attempts_ < retry_policy_.max_attempts);
+#else
+  return false;
+#endif  // ENABLE_OTLP_RETRY_PREVIEW
+}
+
+std::chrono::system_clock::time_point HttpOperation::NextRetryTime()
+{
+  static std::random_device rd;
+  static std::mt19937 gen(rd());
+  static std::uniform_real_distribution<float> dis(0.8, 1.2);
+
+  // The initial retry attempt will occur after initialBackoff * random(0.8, 1.2)
+  auto backoff = retry_policy_.initial_backoff;
+
+  // After that, the n-th attempt will occur after
+  // min(initialBackoff*backoffMultiplier**(n-1), maxBackoff) * random(0.8, 1.2))
+  if (retry_attempts_ > 1)
+  {
+    backoff = (std::min)(retry_policy_.initial_backoff *
+                             std::pow(retry_policy_.backoff_multiplier,
+                                      static_cast<SecondsDecimal::rep>(retry_attempts_ - 1)),
+                         retry_policy_.max_backoff);
+  }
+
+  // Jitter of plus or minus 0.2 is applied to the backoff delay to avoid hammering servers at the
+  // same time from a large number of clients. Note that this means that the backoff delay may
+  // actually be slightly lower than initialBackoff or slightly higher than maxBackoff
+  backoff *= dis(gen);
+
+  return last_attempt_time_ + std::chrono::duration_cast<std::chrono::milliseconds>(backoff);
+}
+
 /*
   Support for TLS min version, TLS max version.
 
@@ -569,8 +632,77 @@ CURLcode HttpOperation::SetCurlOffOption(CURLoption option, curl_off_t value)
   return rc;
 }
 
+int HttpOperation::CurlLoggerCallback(const CURL * /* handle */,
+                                      curl_infotype type,
+                                      const char *data,
+                                      size_t size,
+                                      void * /* clientp */) noexcept
+{
+  nostd::string_view text_to_log{data, size};
+
+  if (!text_to_log.empty() && text_to_log[size - 1] == '\n')
+  {
+    text_to_log = text_to_log.substr(0, size - 1);
+  }
+
+  if (type == CURLINFO_TEXT)
+  {
+    static const auto kTlsInfo    = nostd::string_view("SSL connection using");
+    static const auto kFailureMsg = nostd::string_view("Recv failure:");
+
+    if (text_to_log.substr(0, kTlsInfo.size()) == kTlsInfo)
+    {
+      OTEL_INTERNAL_LOG_INFO(text_to_log);
+    }
+    else if (text_to_log.substr(0, kFailureMsg.size()) == kFailureMsg)
+    {
+      OTEL_INTERNAL_LOG_ERROR(text_to_log);
+    }
+// This guard serves as a catch-all block for all other less interesting output that should
+// remain available for maintainer internal use and for debugging purposes only.
+#ifdef OTEL_CURL_DEBUG
+    else
+    {
+      OTEL_INTERNAL_LOG_DEBUG(text_to_log);
+    }
+#endif  // OTEL_CURL_DEBUG
+  }
+// Same as above, this guard is meant only for internal use by maintainers, and should not be used
+// in production (information leak).
+#ifdef OTEL_CURL_DEBUG
+  else if (type == CURLINFO_HEADER_OUT)
+  {
+    static const auto kHeaderSent = nostd::string_view("Send header => ");
+
+    while (!text_to_log.empty() && !std::iscntrl(text_to_log[0]))
+    {
+      const auto pos = text_to_log.find('\n');
+
+      if (pos != nostd::string_view::npos)
+      {
+        OTEL_INTERNAL_LOG_DEBUG(kHeaderSent << text_to_log.substr(0, pos - 1));
+        text_to_log = text_to_log.substr(pos + 1);
+      }
+    }
+  }
+  else if (type == CURLINFO_HEADER_IN)
+  {
+    static const auto kHeaderRecv = nostd::string_view("Recv header => ");
+    OTEL_INTERNAL_LOG_DEBUG(kHeaderRecv << text_to_log);
+  }
+#endif  // OTEL_CURL_DEBUG
+
+  return 0;
+}
+
 CURLcode HttpOperation::Setup()
 {
+#ifdef ENABLE_CURL_LOGGING
+  static constexpr auto kEnableCurlLogging = true;
+#else
+  static constexpr auto kEnableCurlLogging = false;
+#endif  // ENABLE_CURL_LOGGING
+
   if (!curl_resource_.easy_handle)
   {
     return CURLE_FAILED_INIT;
@@ -581,11 +713,28 @@ CURLcode HttpOperation::Setup()
   curl_error_message_[0] = '\0';
   curl_easy_setopt(curl_resource_.easy_handle, CURLOPT_ERRORBUFFER, curl_error_message_);
 
+// Support for custom debug function callback was added in version 7.9.6 so we guard against
+// exposing the default CURL output by keeping verbosity always disabled in lower versions.
+#if LIBCURL_VERSION_NUM < CURL_VERSION_BITS(7, 9, 6)
   rc = SetCurlLongOption(CURLOPT_VERBOSE, 0L);
   if (rc != CURLE_OK)
   {
     return rc;
   }
+#else
+  rc = SetCurlLongOption(CURLOPT_VERBOSE, (is_log_enabled_ && kEnableCurlLogging) ? 1L : 0L);
+  if (rc != CURLE_OK)
+  {
+    return rc;
+  }
+
+  rc = SetCurlPtrOption(CURLOPT_DEBUGFUNCTION,
+                        reinterpret_cast<void *>(&HttpOperation::CurlLoggerCallback));
+  if (rc != CURLE_OK)
+  {
+    return rc;
+  }
+#endif
 
   // Specify target URL
   rc = SetCurlStrOption(CURLOPT_URL, url_.c_str());
@@ -1111,11 +1260,6 @@ CURLcode HttpOperation::Send()
 
   CURLcode code = curl_easy_perform(curl_resource_.easy_handle);
   PerformCurlMessage(code);
-  if (CURLE_OK != code)
-  {
-    return code;
-  }
-
   return code;
 }
 
@@ -1161,7 +1305,7 @@ CURLcode HttpOperation::SendAsync(Session *session, std::function<void(HttpOpera
   async_data_->callback = std::move(callback);
 
   session->GetHttpClient().ScheduleAddSession(session->GetSessionId());
-  return code;
+  return CURLE_OK;
 }
 
 Headers HttpOperation::GetResponseHeaders()
@@ -1182,7 +1326,7 @@ Headers HttpOperation::GetResponseHeaders()
     // switching to string comparison. Need to debug and revert back.
 
     /*std::smatch match;
-    std::regex http_headers_regex(http_header_regexp);
+    std::regex http_headers_regex(kHttpHeaderRegexp);
     if (std::regex_search(header, match, http_headers_regex))
       result.insert(std::pair<nostd::string_view, nostd::string_view>(
           static_cast<nostd::string_view>(match[1]), static_cast<nostd::string_view>(match[2])));
@@ -1219,7 +1363,10 @@ void HttpOperation::Abort()
 
 void HttpOperation::PerformCurlMessage(CURLcode code)
 {
-  last_curl_result_ = code;
+  ++retry_attempts_;
+  last_attempt_time_ = std::chrono::system_clock::now();
+  last_curl_result_  = code;
+
   if (code != CURLE_OK)
   {
     switch (GetSessionState())
@@ -1265,8 +1412,20 @@ void HttpOperation::PerformCurlMessage(CURLcode code)
     DispatchEvent(opentelemetry::ext::http::client::SessionState::Response);
   }
 
-  // Cleanup and unbind easy handle from multi handle, and finish callback
-  Cleanup();
+  if (IsRetryable())
+  {
+    // Clear any response data received in previous attempt
+    ReleaseResponse();
+    // Rewind request data so that read callback can re-transfer the payload
+    request_nwrite_ = 0;
+    // Reset session state
+    DispatchEvent(opentelemetry::ext::http::client::SessionState::Connecting);
+  }
+  else
+  {
+    // Cleanup and unbind easy handle from multi handle, and finish callback
+    Cleanup();
+  }
 }
 
 }  // namespace curl
