@@ -3,7 +3,21 @@
  * SPDX-License-Identifier: Apache-2.0
  */
 
+#include <functional>
+#include <memory>
+#include <new>
+#include <string>
+
+#include "opentracing/span.h"
+
+#include "opentelemetry/baggage/baggage.h"
+#include "opentelemetry/nostd/function_ref.h"
+#include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/opentracingshim/span_context_shim.h"
+#include "opentelemetry/trace/span_context.h"
+#include "opentelemetry/trace/span_id.h"
+#include "opentelemetry/trace/trace_id.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace opentracingshim
@@ -23,7 +37,7 @@ bool SpanContextShim::BaggageItem(nostd::string_view key, std::string &value) co
 void SpanContextShim::ForeachBaggageItem(VisitBaggageItem f) const
 {
   baggage_->GetAllEntries([&f](nostd::string_view key, nostd::string_view value) {
-    return f(key.data(), value.data());
+    return f(std::string{key.data(), key.size()}, std::string{value.data(), value.size()});
   });
 }
 
