@@ -3,12 +3,13 @@
 
 #pragma once
 
-#ifdef ENABLE_LOGS_PREVIEW
+#include <memory>
+#include <vector>
 
-#  include "opentelemetry/sdk/logs/logger_context.h"
-#  include "opentelemetry/sdk/logs/processor.h"
-#  include "opentelemetry/sdk/resource/resource.h"
-#  include "opentelemetry/version.h"
+#include "opentelemetry/sdk/logs/logger_context.h"
+#include "opentelemetry/sdk/logs/processor.h"
+#include "opentelemetry/sdk/resource/resource.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace sdk
@@ -26,13 +27,13 @@ public:
    * Create a LoggerContext.
    */
   static std::unique_ptr<LoggerContext> Create(
-      std::vector<std::unique_ptr<LogProcessor>> &&processors);
+      std::vector<std::unique_ptr<LogRecordProcessor>> &&processors);
 
   /**
    * Create a LoggerContext.
    */
   static std::unique_ptr<LoggerContext> Create(
-      std::vector<std::unique_ptr<LogProcessor>> &&processors,
+      std::vector<std::unique_ptr<LogRecordProcessor>> &&processors,
       const opentelemetry::sdk::resource::Resource &resource);
 };
 
@@ -40,4 +41,3 @@ public:
 }  // namespace sdk
 
 OPENTELEMETRY_END_NAMESPACE
-#endif
