@@ -65,11 +65,15 @@ public:
 class FilteringAttributesProcessor : public AttributesProcessor
 {
 public:
-  FilteringAttributesProcessor(
-      const std::unordered_map<std::string, bool> allowed_attribute_keys = {})
+  FilteringAttributesProcessor(std::unordered_map<std::string, bool> &&allowed_attribute_keys = {})
       : allowed_attribute_keys_(std::move(allowed_attribute_keys))
   {}
 
+  FilteringAttributesProcessor(
+      const std::unordered_map<std::string, bool> &allowed_attribute_keys = {})
+      : allowed_attribute_keys_(allowed_attribute_keys)
+  {}
+
   MetricAttributes process(
       const opentelemetry::common::KeyValueIterable &attributes) const noexcept override
   {
