@@ -1,12 +1,15 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#ifdef ENABLE_LOGS_PREVIEW
+#include <memory>
+#include <utility>
+#include <vector>
 
-#  include "opentelemetry/sdk/logs/logger_context_factory.h"
-
-#  include <memory>
-#  include <vector>
+#include "opentelemetry/sdk/logs/logger_context.h"
+#include "opentelemetry/sdk/logs/logger_context_factory.h"
+#include "opentelemetry/sdk/logs/processor.h"
+#include "opentelemetry/sdk/resource/resource.h"
+#include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
 namespace sdk
@@ -15,14 +18,14 @@ namespace logs
 {
 
 std::unique_ptr<LoggerContext> LoggerContextFactory::Create(
-    std::vector<std::unique_ptr<LogProcessor>> &&processors)
+    std::vector<std::unique_ptr<LogRecordProcessor>> &&processors)
 {
   auto resource = opentelemetry::sdk::resource::Resource::Create({});
   return Create(std::move(processors), resource);
 }
 
 std::unique_ptr<LoggerContext> LoggerContextFactory::Create(
-    std::vector<std::unique_ptr<LogProcessor>> &&processors,
+    std::vector<std::unique_ptr<LogRecordProcessor>> &&processors,
     const opentelemetry::sdk::resource::Resource &resource)
 {
   std::unique_ptr<LoggerContext> context(new LoggerContext(std::move(processors), resource));
@@ -33,4 +36,3 @@ std::unique_ptr<LoggerContext> LoggerContextFactory::Create(
 }  // namespace sdk
 
 OPENTELEMETRY_END_NAMESPACE
-#endif
