@@ -1,22 +1,25 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include <stdint.h>
 #include <atomic>
 #include <chrono>
 #include <condition_variable>
+#include <cstdint>
 #include <memory>
 #include <mutex>
 #include <ostream>
 #include <ratio>
 #include <thread>
+#include <type_traits>
 #include <utility>
 
 #include "opentelemetry/common/timestamp.h"
+#include "opentelemetry/nostd/function_ref.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
 #include "opentelemetry/sdk/metrics/export/metric_producer.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_options.h"
+#include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_runtime_options.h"
 #include "opentelemetry/sdk/metrics/instruments.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 #include "opentelemetry/version.h"
@@ -40,10 +43,32 @@ namespace metrics
 
 PeriodicExportingMetricReader::PeriodicExportingMetricReader(
     std::unique_ptr<PushMetricExporter> exporter,
-    const PeriodicExportingMetricReaderOptions &option)
+    const PeriodicExportingMetricReaderOptions &options)
     : exporter_{std::move(exporter)},
-      export_interval_millis_{option.export_interval_millis},
-      export_timeout_millis_{option.export_timeout_millis}
+      export_interval_millis_{options.export_interval_millis},
+      export_timeout_millis_{options.export_timeout_millis},
+      worker_thread_instrumentation_(nullptr),
+      collect_thread_instrumentation_(nullptr)
+{
+  if (export_interval_millis_ <= export_timeout_millis_)
+  {
+    OTEL_INTERNAL_LOG_WARN(
+        "[Periodic Exporting Metric Reader] Invalid configuration: "
+        "export_timeout_millis_ should be less than export_interval_millis_, using default values");
+    export_interval_millis_ = kExportIntervalMillis;
+    export_timeout_millis_  = kExportTimeOutMillis;
+  }
+}
+
+PeriodicExportingMetricReader::PeriodicExportingMetricReader(
+    std::unique_ptr<PushMetricExporter> exporter,
+    const PeriodicExportingMetricReaderOptions &options,
+    const PeriodicExportingMetricReaderRuntimeOptions &runtime_options)
+    : exporter_{std::move(exporter)},
+      export_interval_millis_{options.export_interval_millis},
+      export_timeout_millis_{options.export_timeout_millis},
+      worker_thread_instrumentation_(runtime_options.periodic_thread_instrumentation),
+      collect_thread_instrumentation_(runtime_options.collect_thread_instrumentation)
 {
   if (export_interval_millis_ <= export_timeout_millis_)
   {
@@ -67,18 +92,50 @@ void PeriodicExportingMetricReader::OnInitialized() noexcept
 
 void PeriodicExportingMetricReader::DoBackgroundWork()
 {
-  std::unique_lock<std::mutex> lk(cv_m_);
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+  if (worker_thread_instrumentation_ != nullptr)
+  {
+    worker_thread_instrumentation_->OnStart();
+  }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
   do
   {
-    auto start  = std::chrono::steady_clock::now();
+    auto start = std::chrono::steady_clock::now();
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+    if (worker_thread_instrumentation_ != nullptr)
+    {
+      worker_thread_instrumentation_->BeforeLoad();
+    }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
     auto status = CollectAndExportOnce();
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+    if (worker_thread_instrumentation_ != nullptr)
+    {
+      worker_thread_instrumentation_->AfterLoad();
+    }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
     if (!status)
     {
       OTEL_INTERNAL_LOG_ERROR("[Periodic Exporting Metric Reader]  Collect-Export Cycle Failure.")
     }
+
     auto end            = std::chrono::steady_clock::now();
     auto export_time_ms = std::chrono::duration_cast<std::chrono::milliseconds>(end - start);
     auto remaining_wait_interval_ms = export_interval_millis_ - export_time_ms;
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+    if (worker_thread_instrumentation_ != nullptr)
+    {
+      worker_thread_instrumentation_->BeforeWait();
+    }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
+    std::unique_lock<std::mutex> lk(cv_m_);
     cv_.wait_for(lk, remaining_wait_interval_ms, [this]() {
       if (is_force_wakeup_background_worker_.load(std::memory_order_acquire))
       {
@@ -87,7 +144,22 @@ void PeriodicExportingMetricReader::DoBackgroundWork()
       }
       return IsShutdown();
     });
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+    if (worker_thread_instrumentation_ != nullptr)
+    {
+      worker_thread_instrumentation_->AfterWait();
+    }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
   } while (IsShutdown() != true);
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+  if (worker_thread_instrumentation_ != nullptr)
+  {
+    worker_thread_instrumentation_->OnEnd();
+  }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
 }
 
 bool PeriodicExportingMetricReader::CollectAndExportOnce()
@@ -106,6 +178,14 @@ bool PeriodicExportingMetricReader::CollectAndExportOnce()
 
     task_thread.reset(
         new std::thread([this, &cancel_export_for_timeout, sender = std::move(sender)] {
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+          if (collect_thread_instrumentation_ != nullptr)
+          {
+            collect_thread_instrumentation_->OnStart();
+            collect_thread_instrumentation_->BeforeLoad();
+          }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
+
           this->Collect([this, &cancel_export_for_timeout](ResourceMetrics &metric_data) {
             if (cancel_export_for_timeout.load(std::memory_order_acquire))
             {
@@ -119,6 +199,14 @@ bool PeriodicExportingMetricReader::CollectAndExportOnce()
           });
 
           const_cast<std::promise<void> &>(sender).set_value();
+
+#ifdef ENABLE_THREAD_INSTRUMENTATION_PREVIEW
+          if (collect_thread_instrumentation_ != nullptr)
+          {
+            collect_thread_instrumentation_->AfterLoad();
+            collect_thread_instrumentation_->OnEnd();
+          }
+#endif /* ENABLE_THREAD_INSTRUMENTATION_PREVIEW */
         }));
 
     std::future_status status;
