@@ -17,6 +17,7 @@
 #include "opentelemetry/sdk/metrics/meter_context.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
 #include "opentelemetry/sdk/metrics/state/metric_collector.h"
+#include "opentelemetry/sdk/resource/resource.h"
 #include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -36,7 +37,18 @@ MetricCollector::MetricCollector(opentelemetry::sdk::metrics::MeterContext *cont
 AggregationTemporality MetricCollector::GetAggregationTemporality(
     InstrumentType instrument_type) noexcept
 {
-  return metric_reader_->GetAggregationTemporality(instrument_type);
+  auto aggregation_temporality = metric_reader_->GetAggregationTemporality(instrument_type);
+  if (aggregation_temporality == AggregationTemporality::kDelta &&
+      instrument_type == InstrumentType::kGauge)
+  {
+    OTEL_INTERNAL_LOG_ERROR(
+        "[MetricCollector::GetAggregationTemporality] - Error getting aggregation temporality."
+        << "Delta temporality for Synchronous Gauge is currently not supported, using cumulative "
+           "temporality");
+
+    return AggregationTemporality::kCumulative;
+  }
+  return aggregation_temporality;
 }
 
 MetricProducer::Result MetricCollector::Produce() noexcept
