@@ -11,9 +11,7 @@
 #include <utility>
 #include <vector>
 
-#include "opentelemetry/nostd/function_ref.h"
 #include "opentelemetry/sdk/common/exporter_utils.h"
-#include "opentelemetry/sdk/metrics/data/point_data.h"
 #include "opentelemetry/sdk/metrics/export/metric_producer.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_options.h"
