@@ -3,21 +3,20 @@
 
 #include <gtest/gtest.h>
 #include <algorithm>
-#include <memory>
+#include <initializer_list>
 #include <string>
 #include <unordered_map>
 #include <utility>
 #include <vector>
 #include "common.h"
 
-#include "opentelemetry/common/attribute_value.h"
 #include "opentelemetry/common/macros.h"
 #include "opentelemetry/context/context.h"
 #include "opentelemetry/metrics/meter.h"
 #include "opentelemetry/metrics/sync_instruments.h"
-#include "opentelemetry/nostd/string_view.h"
+#include "opentelemetry/nostd/function_ref.h"
+#include "opentelemetry/nostd/shared_ptr.h"
 #include "opentelemetry/nostd/variant.h"
-#include "opentelemetry/sdk/common/exporter_utils.h"
 #include "opentelemetry/sdk/metrics/aggregation/aggregation_config.h"
 #include "opentelemetry/sdk/metrics/data/metric_data.h"
 #include "opentelemetry/sdk/metrics/data/point_data.h"
